@@ -8,7 +8,7 @@ if (!function_exists('logger')) {
     function logger(string $stream = loggerStore::DEFAULT__LOGGER_STREAM): loggerInterface
     {
         try {
-            return loggerStore::getInstance()->logger($stream);
+            return container()->get(loggerStore::class)->logger($stream);
         } catch (Throwable $e) {
             error_log(
                 sprintf(
