@@ -4,15 +4,15 @@ declare(strict_types=1);
 
 namespace apexl\Io\modules\logger\hooks;
 
-use apexl\Io\hooks\AbstractHook;
+use apexl\Io\interfaces\AbstractHook;
 use apexl\Io\modules\logger\traits\getsSimpleTrace;
 use Throwable;
 
-final readonly class errorListener extends AbstractHook
+final readonly class errorListener implements AbstractHook
 {
     use getsSimpleTrace;
 
-    static protected function hooks(): array
+    public function hooks(): array
     {
         return ['error'];
     }
